@@ -28,13 +28,14 @@ class _LazyModule:
 # NOTE: Add additional used imports here.
 if TYPE_CHECKING:
     import onnx
+    import onnx_ir  # type: ignore[import-untyped]
     import onnxscript
-    import onnxscript._framework_apis.torch_2_7 as onnxscript_apis
+    import onnxscript._framework_apis.torch_2_8 as onnxscript_apis
 
-    onnxscript_ir = onnxscript.ir
+    onnxscript_ir = onnx_ir
 
 else:
     onnx = _LazyModule("onnx")
     onnxscript = _LazyModule("onnxscript")
-    onnxscript_ir = _LazyModule("onnxscript.ir")
-    onnxscript_apis = _LazyModule("onnxscript._framework_apis.torch_2_7")
+    onnxscript_ir = _LazyModule("onnx_ir")
+    onnxscript_apis = _LazyModule("onnxscript._framework_apis.torch_2_8")
